pub struct RestoreReport {
pub value: Value,
pub disclosed: usize,
pub decoys: usize,
pub removed_redactions: usize,
}Expand description
Result of restoring disclosed SD-CWT claims.
Fields
value: ValueThe restored claims value.
disclosed: usizeNumber of map claims or array elements restored from disclosures.
decoys: usizeNumber of matching decoy redactions removed.
removed_redactions: usizeNumber of redactions removed because no disclosure was presented.